Reader

Struct Reader 

pub struct Reader<S: AsRef<[u8]>> {
    pub metadata: Metadata,
    /* private fields */
}
A reader for the MaxMind DB format. The lifetime 'data is tied to the lifetime of the underlying buffer holding the contents of the database file.

Fields

metadata: Metadata

Implementations

Source

impl Reader<Vec<u8>>

pub fn open_readfile<P: AsRef<Path>>( database: P, ) -> Result<Reader<Vec<u8>>, MaxMindDBError>

Open a MaxMind DB database file by loading it into memory.

Example
let reader = maxminddb::Reader::open_readfile("test-data/test-data/GeoIP2-City-Test.mmdb").unwrap();
Source

impl<'de, S: AsRef<[u8]>> Reader<S>

pub fn from_source(buf: S) -> Result<Reader<S>, MaxMindDBError>

Open a MaxMind DB database from anything that implements AsRef<u8>

Example
use std::fs;
let buf = fs::read("test-data/test-data/GeoIP2-City-Test.mmdb").unwrap();
let reader = maxminddb::Reader::from_source(buf).unwrap();
pub fn lookup<T>(&'de self, address: IpAddr) -> Result<T, MaxMindDBError>
where T: Deserialize<'de>,

Lookup the socket address in the opened MaxMind DB

Example:

use maxminddb::geoip2;
use std::net::IpAddr;
use std::str::FromStr;

let reader = maxminddb::Reader::open_readfile("test-data/test-data/GeoIP2-City-Test.mmdb").unwrap();

let ip: IpAddr = FromStr::from_str("89.160.20.128").unwrap();
let city: geoip2::City = reader.lookup(ip).unwrap();
print!("{:?}", city);
pub fn lookup_prefix<T>( &'de self, address: IpAddr, ) -> Result<(T, usize), MaxMindDBError>
where T: Deserialize<'de>,

Lookup the socket address in the opened MaxMind DB

Example:

use maxminddb::geoip2;
use std::net::IpAddr;
use std::str::FromStr;

let reader = maxminddb::Reader::open_readfile("test-data/test-data/GeoIP2-City-Test.mmdb").unwrap();

let ip: IpAddr = "89.160.20.128".parse().unwrap();
let (city, prefix_len) = reader.lookup_prefix::<geoip2::City>(ip).unwrap();
print!("{:?}, prefix length: {}", city, prefix_len);
pub fn within<T>( &'de self, cidr: IpNetwork, ) -> Result<Within<'de, T, S>, MaxMindDBError>
where T: Deserialize<'de>,

Iterate over blocks of IP networks in the opened MaxMind DB

Example:

use ipnetwork::IpNetwork;
use maxminddb::{geoip2, Within};

let reader = maxminddb::Reader::open_readfile("test-data/test-data/GeoIP2-City-Test.mmdb").unwrap();

let ip_net = IpNetwork::V6("::/0".parse().unwrap());
let mut iter: Within<geoip2::City, _> = reader.within(ip_net).unwrap();
while let Some(next) = iter.next() {
    let item = next.unwrap();
    println!("ip_net={}, city={:?}", item.ip_net, item.info);
}